@@ -158,8 +158,8 @@ impl App {
             NextTab => self.model().tabs.next(),
             PrevTab => self.model().tabs.previous(),
             SetTab(tab) => self.model().tabs.set(tab.index()),
-            VolumeUp => volume::change_volume(self, 1),
-            VolumeDown => volume::change_volume(self, -1),
+            ChangeVolume(v) => volume::change_volume(self, *v as i8),
+            SetVolume(v) => volume::set_volume(self, *v as i8),
             Quit => self.quit(),
             _ => {}
         }
