@@ -1,9 +1,10 @@
 use crate::{Context, Message};
 use serde::{Deserialize, Serialize};
 use std::{collections::HashMap, env, fs, path::Path};
+use crate::util::ui_util::AppStyle;
 
 pub type KeyConfig = HashMap<Context, HashMap<String, Message>>;
-pub type ThemeConfig = HashMap<String, String>;
+pub type ThemeConfig = HashMap<AppStyle, String>;
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct Config {
