@@ -26,8 +26,9 @@ pub enum Message {
     Play,
     ListExpand,
     ListCollapse,
-    VolumeUp,
-    VolumeDown,
+
+    ChangeVolume(i32),
+    SetVolume(i32),
 
     Rescan,
     Seek(i32),
