@@ -21,7 +21,7 @@ use crate::{
     view::View,
 };
 use backtrace::Backtrace;
-use config::Config;
+use config::{Config, ThemeConfig};
 use mpd::{
     idle::{Idle, Subsystem},
     Channel,
@@ -47,6 +47,17 @@ pub fn get_subsytems() -> Vec<Subsystem> {
     ]
 }
 
+pub fn subsystem_messages(subsystem: Subsystem) -> Vec<Message> {
+    match subsystem {
+        Subsystem::Player => vec![Message::UpdatePlayer, Message::UpdateQueue],
+        Subsystem::Database => vec![Message::UpdateLibrary, Message::UpdatePlaylists],
+        Subsystem::Mixer => vec![Message::UpdateVolume],
+        Subsystem::Playlist => vec![Message::UpdatePlaylists],
+        Subsystem::Queue => vec![Message::UpdateQueue],
+        _ => vec![],
+    }
+}
+
 pub fn control_thread(app: Arc<App>) {
     let mut workers = Vec::with_capacity(app.config().event_threads as usize);
 
@@ -108,7 +119,8 @@ pub fn mpd_listen_thread(app: Arc<App>) {
 
             subsystems
                 .into_iter()
-                .map(|s| s.into())
+                .map(|s| subsystem_messages(s))
+                .flatten()
                 .for_each(|message: Message| {
                     send_message(&app, message);
                 });
