@@ -5,6 +5,7 @@ use tui::{
     text::Span,
     widgets::{Block, Borders, ListState, TableState},
 };
+use serde::{Serialize, Deserialize};
 
 pub fn color_from_hex(hex: &str) -> Color {
     let hex = i64::from_str_radix(hex.strip_prefix("#").expect("Invalid color"), 16).unwrap();
@@ -16,10 +17,11 @@ pub fn color_from_hex(hex: &str) -> Color {
     Color::Rgb(r, g, b)
 }
 
-pub fn theme_color(theme: &ThemeConfig, color: &str) -> Option<Color> {
-    theme.get(color).map(|hex| color_from_hex(hex))
+pub fn theme_color(theme: &ThemeConfig, style: &AppStyle) -> Option<Color> {
+    theme.get(&style).map(|hex| color_from_hex(hex))
 }
 
+#[derive(Serialize, Deserialize, Debug, Clone, Hash, PartialEq, Eq)]
 pub enum AppStyle {
     Border,
     FrameTitle,
@@ -28,34 +30,27 @@ pub enum AppStyle {
     Player,
 }
 
-fn fg_style(theme: &ThemeConfig, color: &str) -> Style {
-    Style::default().fg(theme_color(&theme, color).unwrap_or(Color::White))
+fn fg_style(theme: &ThemeConfig, style: &AppStyle) -> Style {
+    Style::default().fg(theme_color(&theme, &style).unwrap_or(Color::White))
 }
 
-pub fn get_style(theme: &ThemeConfig, style: AppStyle) -> Style {
-    use AppStyle::*;
-    match style {
-        Border => fg_style(&theme, "color_border"),
-        FrameTitle => fg_style(&theme, "color_frame_title"),
-        TabTitle => fg_style(&theme, "color_tab_title"),
-        ContentText => fg_style(&theme, "color_text"),
-        Player => fg_style(&theme, "color_player"),
-    }
+pub fn get_style(theme: &ThemeConfig, style: &AppStyle) -> Style {
+    fg_style(theme, &style)
 }
 
 pub fn frame_title_span(theme: &ThemeConfig, title: String) -> Span {
-    return Span::styled(title, get_style(theme, AppStyle::FrameTitle));
+    return Span::styled(title, get_style(theme, &AppStyle::FrameTitle));
 }
 
 pub fn create_content_frame(theme: &ThemeConfig, title: String) -> Block {
     Block::default()
         .title(frame_title_span(&theme, title))
         .borders(Borders::ALL)
-        .border_style(get_style(&theme, AppStyle::Border))
+        .border_style(get_style(&theme, &AppStyle::Border))
 }
 
 pub fn table_style(theme: &ThemeConfig) -> Style {
-    get_style(&theme, AppStyle::ContentText)
+    get_style(&theme, &AppStyle::ContentText)
 }
 
 #[derive(Debug, Clone)]
