@@ -1,25 +1,30 @@
-use crate::{model::PlaylistsModel, AppBackend};
+use crate::{
+    model::PlaylistsModel,
+    util::ui_util,
+    AppBackend, ThemeConfig,
+};
 
 use mpd::Playlist;
 use tui::{
     layout::{Constraint, Rect},
-    style::{Color, Modifier, Style},
+    style::{Modifier, Style},
     terminal::Frame,
-    widgets::{Block, Borders, Row, Table},
+    widgets::{Row, Table},
 };
 
-pub fn view(playlists: &mut PlaylistsModel, f: &mut Frame<AppBackend>, area: Rect) {
+pub fn view(
+    playlists: &mut PlaylistsModel,
+    theme: &ThemeConfig,
+    f: &mut Frame<AppBackend>,
+    area: Rect,
+) {
     let items = playlists.items.items.iter().map(|list| {
         let lines = parse_list(&list).into_iter();
         Row::Data(lines)
     });
     let items = Table::new(vec!["  Name"].into_iter(), items)
-        .block(
-            Block::default()
-                .title("Playlists")
-                .borders(Borders::ALL)
-                .style(Style::default().fg(Color::Cyan)),
-        )
+        .style(ui_util::table_style(&theme))
+        .block(ui_util::create_content_frame(&theme, "Playlists".into()))
         .highlight_style(Style::default().add_modifier(Modifier::BOLD))
         .highlight_symbol("→ ")
         .widths(&[Constraint::Percentage(100)]);
