@@ -21,7 +21,7 @@ pub fn view(
             &theme,
             progress_bar.state().into(),
         ))
-        .gauge_style(ui_util::get_style(&theme, AppStyle::Player))
+        .gauge_style(ui_util::get_style(&theme, &AppStyle::Player))
         .percent(progress_bar.get_progress());
 
     f.render_widget(gauge, area);
